@@ -15,7 +15,7 @@
 
 class CloudConfig(object):
     def __init__(self, name, region, config):
-        self.name = name or 'openstack'
+        self.name = name
         self.region = region
         self.config = config
 
@@ -32,3 +32,10 @@ class CloudConfig(object):
 
     def __iter__(self):
         return self.config.__iter__()
+
+    def __eq__(self, other):
+        return (self.name == other.name and self.region == other.region
+                and self.config == other.config)
+
+    def __ne__(self, other):
+        return not self == other
