@@ -108,7 +108,7 @@ class OpenStackConfig(object):
             self.defaults.update(override_defaults)
 
         # First, use a config file if it exists where expected
-        self.cloud_config = self._load_config_file()
+        self.config_filename, self.cloud_config = self._load_config_file()
 
         if not self.cloud_config:
             self.cloud_config = {'clouds': {}}
@@ -161,7 +161,18 @@ class OpenStackConfig(object):
         for path in filelist:
             if os.path.exists(path):
                 with open(path, 'r') as f:
-                    return yaml.safe_load(f)
+                    return path, self._normalize_keys(yaml.safe_load(f))
+        return (None, None)
+
+    def _normalize_keys(self, config):
+        new_config = {}
+        for key, value in config.items():
+            key = key.replace('-', '_')
+            if isinstance(value, dict):
+                new_config[key] = self._normalize_keys(value)
+            else:
+                new_config[key] = value
+        return new_config
 
     def get_cache_max_age(self):
         return self._cache_max_age
@@ -185,7 +196,7 @@ class OpenStackConfig(object):
     def _get_region(self, cloud=None):
         return self._get_regions(cloud).split(',')[0]
 
-    def _get_cloud_sections(self):
+    def get_cloud_names(self):
         return self.cloud_config['clouds'].keys()
 
     def _get_base_cloud_config(self, name):
@@ -202,15 +213,16 @@ class OpenStackConfig(object):
         # Get the defaults
         cloud.update(self.defaults)
 
-        # yes, I know the next line looks silly
-        if 'cloud' in our_cloud:
-            cloud_name = our_cloud['cloud']
-            vendor_file = self._load_vendor_file()
-            if vendor_file and cloud_name in vendor_file['public-clouds']:
-                _auth_update(cloud, vendor_file['public-clouds'][cloud_name])
+        # Expand a profile if it exists. 'cloud' is an old confusing name
+        # for this.
+        profile_name = our_cloud.get('profile', our_cloud.get('cloud', None))
+        if profile_name:
+            vendor_filename, vendor_file = self._load_vendor_file()
+            if vendor_file and profile_name in vendor_file['public_clouds']:
+                _auth_update(cloud, vendor_file['public_clouds'][profile_name])
             else:
                 try:
-                    _auth_update(cloud, vendors.CLOUD_DEFAULTS[cloud_name])
+                    _auth_update(cloud, vendors.CLOUD_DEFAULTS[profile_name])
                 except KeyError:
                     # Can't find the requested vendor config, go about business
                     pass
@@ -266,7 +278,7 @@ class OpenStackConfig(object):
 
         clouds = []
 
-        for cloud in self._get_cloud_sections():
+        for cloud in self.get_cloud_names():
             for region in self._get_regions(cloud).split(','):
                 clouds.append(self.get_one_cloud(cloud, region_name=region))
         return clouds
@@ -369,7 +381,7 @@ class OpenStackConfig(object):
         :param kwargs: Additional configuration options
         """
 
-        if cloud is None and self.envvar_key in self._get_cloud_sections():
+        if cloud is None and self.envvar_key in self.get_cloud_names():
             cloud = self.envvar_key
 
         args = self._fix_args(kwargs, argparse=argparse)
@@ -404,8 +416,12 @@ class OpenStackConfig(object):
             if hasattr(value, 'format'):
                 config[key] = value.format(**config)
 
+        if cloud is None:
+            cloud_name = ''
+        else:
+            cloud_name = str(cloud)
         return cloud_config.CloudConfig(
-            name=cloud, region=config['region_name'], config=config)
+            name=cloud_name, region=config['region_name'], config=config)
 
 if __name__ == '__main__':
     config = OpenStackConfig().get_all_clouds()
